"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("@deep-foundation/hasura/client");
const client_2 = require("../imports/client");
const chai_1 = require("chai");
const apolloClient = (0, client_1.generateApolloClient)({
    path: `${process.env.HASURA_PATH}/v1/graphql`,
    ssl: !!+process.env.HASURA_SSL,
    secret: process.env.HASURA_SECRET,
}, {
    ApolloClient: {
        defaultOptions: {
            watchQuery: {
                errorPolicy: 'all',
            },
        },
    },
});
const deep = new client_2.DeepClient({ apolloClient });
describe('selectors', () => {
    it(`selector include exclude`, () => __awaiter(void 0, void 0, void 0, function* () {
        const { data: [{ id: ty0 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Type'),
        });
        const { data: [{ id: ty1 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Type'),
            from_id: ty0,
            to_id: ty0,
        });
        const { data: [{ id: tr1 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Tree'),
            out: { data: [
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'TreeIncludeDown'),
                        to_id: ty1,
                    },
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'TreeIncludeNode'),
                        to_id: ty0,
                    },
                ] }
        });
        const { data: [{ id: ty2 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Type'),
            from_id: ty0,
            to_id: ty0,
        });
        const { data: [{ id: tr2 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Tree'),
            out: { data: [
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'TreeIncludeDown'),
                        to_id: ty2,
                    },
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'TreeIncludeNode'),
                        to_id: ty0,
                    },
                ] }
        });
        const { data: [{ id: id0 }] } = yield deep.insert({
            type_id: ty0,
        });
        const { data: [{ id: id1 }] } = yield deep.insert({
            type_id: ty0,
            in: { data: {
                    type_id: ty1,
                    from_id: id0,
                } }
        });
        const { data: [{ id: id2 }] } = yield deep.insert({
            type_id: ty0,
            in: { data: {
                    type_id: ty1,
                    from_id: id1,
                } }
        });
        const { data: [{ id: id3 }] } = yield deep.insert({
            type_id: ty0,
            in: { data: {
                    type_id: ty1,
                    from_id: id1,
                } }
        });
        const { data: [{ id: id4 }] } = yield deep.insert({
            type_id: ty0,
            in: { data: {
                    type_id: ty1,
                    from_id: id3,
                } }
        });
        const { data: [{ id: id5 }] } = yield deep.insert({
            type_id: ty0,
            in: { data: {
                    type_id: ty2,
                    from_id: id0,
                } }
        });
        const { data: [{ id: s1 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Selector'),
            out: { data: [
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'Include'),
                        to_id: id0,
                        out: { data: {
                                type_id: yield deep.id('@deep-foundation/core', 'SelectorTree'),
                                to_id: tr1
                            } },
                    },
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'Exclude'),
                        to_id: id3,
                        out: { data: {
                                type_id: yield deep.id('@deep-foundation/core', 'SelectorTree'),
                                to_id: tr1
                            } },
                    },
                ] }
        });
        const { data: [{ id: s2 }] } = yield deep.insert({
            type_id: yield deep.id('@deep-foundation/core', 'Selector'),
            out: { data: [
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'Include'),
                        to_id: id0,
                        out: { data: {
                                type_id: yield deep.id('@deep-foundation/core', 'SelectorTree'),
                                to_id: tr2
                            } },
                    },
                    {
                        type_id: yield deep.id('@deep-foundation/core', 'Exclude'),
                        to_id: id3,
                        out: { data: {
                                type_id: yield deep.id('@deep-foundation/core', 'SelectorTree'),
                                to_id: tr2
                            } },
                    },
                ] }
        });
        const n1 = yield deep.select({
            item_id: { _eq: id2 }, selector_id: { _eq: s1 }
        }, { table: 'selectors', returning: 'item_id selector_id' });
        chai_1.assert.lengthOf(n1 === null || n1 === void 0 ? void 0 : n1.data, 1);
        const n2 = yield deep.select({
            item_id: { _eq: id3 }, selector_id: { _eq: s1 }
        }, { table: 'selectors', returning: 'item_id selector_id' });
        chai_1.assert.lengthOf(n2 === null || n2 === void 0 ? void 0 : n2.data, 0);
        const n3 = yield deep.select({
            item_id: { _eq: id4 }, selector_id: { _eq: s1 }
        }, { table: 'selectors', returning: 'item_id selector_id' });
        chai_1.assert.lengthOf(n3 === null || n3 === void 0 ? void 0 : n3.data, 0);
        const n4 = yield deep.select({
            item_id: { _eq: id5 }, selector_id: { _eq: s1 }
        }, { table: 'selectors', returning: 'item_id selector_id' });
        chai_1.assert.lengthOf(n4 === null || n4 === void 0 ? void 0 : n4.data, 0);
        const n5 = yield deep.select({
            item_id: { _eq: id5 }, selector_id: { _eq: s2 }
        }, { table: 'selectors', returning: 'item_id selector_id' });
        chai_1.assert.lengthOf(n5 === null || n5 === void 0 ? void 0 : n5.data, 1);
    }));
});
//# sourceMappingURL=selectors.js.map